pub struct Instant;Trait Implementations
Sourceimpl<T: ?Sized> CreateHandle<Instant> for Box<T>
impl<T: ?Sized> CreateHandle<Instant> for Box<T>
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourceimpl<'b, T> CreateHandle<Instant> for RefMut<'b, T>
impl<'b, T> CreateHandle<Instant> for RefMut<'b, T>
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourcetype Handle = CellMutHandle<'b, T>
type Handle = CellMutHandle<'b, T>
The handle that’s used for operating on the represented place. Read more
Sourceimpl<'a, T: ?Sized> CreateHandle<Instant> for &'a T
impl<'a, T: ?Sized> CreateHandle<Instant> for &'a T
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourceimpl<'a, T: ?Sized> CreateHandle<Instant> for &'a mut T
impl<'a, T: ?Sized> CreateHandle<Instant> for &'a mut T
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourceimpl<T: ?Sized> CreateHandle<Instant> for NonNull<T>
impl<T: ?Sized> CreateHandle<Instant> for NonNull<T>
Sourceconst ACCESS: AccessKind = AccessKind::Untracked
const ACCESS: AccessKind = AccessKind::Untracked
The access permissions required by
Self::handle_from_raw.Sourceimpl<T: ?Sized> CreateHandle<Instant> for *const T
impl<T: ?Sized> CreateHandle<Instant> for *const T
Sourceconst ACCESS: AccessKind = AccessKind::Untracked
const ACCESS: AccessKind = AccessKind::Untracked
The access permissions required by
Self::handle_from_raw.Sourceimpl<T: ?Sized> CreateHandle<Instant> for *mut T
impl<T: ?Sized> CreateHandle<Instant> for *mut T
Sourceconst ACCESS: AccessKind = AccessKind::Untracked
const ACCESS: AccessKind = AccessKind::Untracked
The access permissions required by
Self::handle_from_raw.Sourceimpl<T: ?Sized> CreateHandle<Instant> for Arc<T>
impl<T: ?Sized> CreateHandle<Instant> for Arc<T>
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourceimpl<T: ?Sized> CreateHandle<Instant> for ArcRef<T>
impl<T: ?Sized> CreateHandle<Instant> for ArcRef<T>
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourcetype Handle = ArcRefHandle<T>
type Handle = ArcRefHandle<T>
The handle that’s used for operating on the represented place. Read more
Sourceimpl<T> CreateHandle<Instant> for Vec<T>
impl<T> CreateHandle<Instant> for Vec<T>
Sourceconst ACCESS: AccessKind = AccessKind::Shared
const ACCESS: AccessKind = AccessKind::Shared
The access permissions required by
Self::handle_from_raw.Sourceimpl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for LocalHandle<P>where
P: CreateHandle<ProxyTiming>,
ProxyTiming: Timing,
impl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for LocalHandle<P>where
P: CreateHandle<ProxyTiming>,
ProxyTiming: Timing,
Sourceconst POINTEE_ACCESS: AccessKind = P::ACCESS
const POINTEE_ACCESS: AccessKind = P::ACCESS
The access permissions to the contents of the place handled by
Self
required by Self::deref_place.Sourceconst POINTER_ACCESS: AccessKind = P::ACCESS
const POINTER_ACCESS: AccessKind = P::ACCESS
The access permissions to the place handled by
Self required by
Self::deref_place.Sourceconst SAFE: bool = true
const SAFE: bool = true
Whether
Self::deref_place is safe when Self::POINTEE_ACCESS and
Self::POINTER_ACCESS are honored for PointeeTiming and
PointerTiming respectively. Read moreunsafe fn deref_place( self, ) -> <Self::Target as CreateHandle<ProxyTiming>>::Handle
Sourceimpl<'a, ProxyTiming, P> DerefPlace<ProxyTiming, Instant> for RefHandle<'a, P>
impl<'a, ProxyTiming, P> DerefPlace<ProxyTiming, Instant> for RefHandle<'a, P>
Sourceconst POINTEE_ACCESS: AccessKind = P::ACCESS
const POINTEE_ACCESS: AccessKind = P::ACCESS
The access permissions to the contents of the place handled by
Self
required by Self::deref_place.Sourceconst POINTER_ACCESS: AccessKind = AccessKind::Shared
const POINTER_ACCESS: AccessKind = AccessKind::Shared
The access permissions to the place handled by
Self required by
Self::deref_place.Sourceconst SAFE: bool = true
const SAFE: bool = true
Whether
Self::deref_place is safe when Self::POINTEE_ACCESS and
Self::POINTER_ACCESS are honored for PointeeTiming and
PointerTiming respectively. Read moreunsafe fn deref_place( self, ) -> <Self::Target as CreateHandle<ProxyTiming>>::Handle
Sourceimpl<'a, ProxyTiming, P> DerefPlace<ProxyTiming, Instant> for MutHandle<'a, P>
impl<'a, ProxyTiming, P> DerefPlace<ProxyTiming, Instant> for MutHandle<'a, P>
Sourceconst POINTEE_ACCESS: AccessKind = P::ACCESS
const POINTEE_ACCESS: AccessKind = P::ACCESS
The access permissions to the contents of the place handled by
Self
required by Self::deref_place.Sourceconst POINTER_ACCESS: AccessKind = AccessKind::Shared
const POINTER_ACCESS: AccessKind = AccessKind::Shared
The access permissions to the place handled by
Self required by
Self::deref_place.Sourceconst SAFE: bool = true
const SAFE: bool = true
Whether
Self::deref_place is safe when Self::POINTEE_ACCESS and
Self::POINTER_ACCESS are honored for PointeeTiming and
PointerTiming respectively. Read moreunsafe fn deref_place( self, ) -> <Self::Target as CreateHandle<ProxyTiming>>::Handle
Sourceimpl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for *const P
impl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for *const P
Sourceconst POINTEE_ACCESS: AccessKind = P::ACCESS
const POINTEE_ACCESS: AccessKind = P::ACCESS
The access permissions to the contents of the place handled by
Self
required by Self::deref_place.Sourceconst POINTER_ACCESS: AccessKind = AccessKind::Untracked
const POINTER_ACCESS: AccessKind = AccessKind::Untracked
The access permissions to the place handled by
Self required by
Self::deref_place.Sourceconst SAFE: bool = false
const SAFE: bool = false
Whether
Self::deref_place is safe when Self::POINTEE_ACCESS and
Self::POINTER_ACCESS are honored for PointeeTiming and
PointerTiming respectively. Read moreunsafe fn deref_place( self, ) -> <Self::Target as CreateHandle<ProxyTiming>>::Handle
Sourceimpl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for *mut P
impl<P, ProxyTiming> DerefPlace<ProxyTiming, Instant> for *mut P
Sourceconst POINTEE_ACCESS: AccessKind = P::ACCESS
const POINTEE_ACCESS: AccessKind = P::ACCESS
The access permissions to the contents of the place handled by
Self
required by Self::deref_place.Sourceconst POINTER_ACCESS: AccessKind = AccessKind::Untracked
const POINTER_ACCESS: AccessKind = AccessKind::Untracked
The access permissions to the place handled by
Self required by
Self::deref_place.Sourceconst SAFE: bool = false
const SAFE: bool = false
Whether
Self::deref_place is safe when Self::POINTEE_ACCESS and
Self::POINTER_ACCESS are honored for PointeeTiming and
PointerTiming respectively. Read moreunsafe fn deref_place( self, ) -> <Self::Target as CreateHandle<ProxyTiming>>::Handle
impl Sealed for Instant
impl Timing for Instant